houba() sends back the list of all options. houba(option = value)
sets the option value. houba("option") sends back the value of an option.
Currently the only supported option is "max.size". Use houba("max.size") to
to get its value and, for example, houba(max.size = 1e3), to set it to 1000.
When subsetting an mvector or an mmatrix, if the size of the resulting object
is greater than `max.size`, then the result will be a memory mapped object (mvector or mmatrix),
else if will be a R object (vector or matrix).
The default value is 1e6.
Set `max.size` to `0` to always get a memory mapped object and to `Inf` to always get a R object.